<?php
/*
  $Id: create_account.php,v 1.2 2006/07/16 05:09:35 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2002 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

define('NAVBAR_TITLE', 'Ȥκ');
define('HEADING_TITLE', 'Ⱦ');
define('TEXT_ORIGIN_LOGIN', ': ˥ȤƤϡ<a href="%s">ڡ</a>󤷤Ƥ');
?>